@@ -1,12 +1,12 @@
 package Datahub::Factory;
 
-our $VERSION = '1.6.1';
+our $VERSION = '1.1';
 
 use Datahub::Factory::Sane;
 
 use Datahub::Factory::Env;
 use Datahub::Factory::Config;
-use Datahub::Factory::Pipeline;
+use Datahub::Factory::PipelineConfig;
 use namespace::clean;
 use Sub::Exporter::Util qw(curry_method);
 use Sub::Exporter -setup => {
@@ -90,6 +90,7 @@ __END__
 
 =encoding utf-8
 
+
 =head1 NAME
 
 =for html <a href="https://travis-ci.org/thedatahub/Datahub-Factory"><img src="https://travis-ci.org/thedatahub/Datahub-Factory.svg?branch=master"></a>
@@ -142,11 +143,6 @@ Set the log_level. Takes a numeric parameter. Supported levels are:
 
 Selects an output for the log messages. By default, it will send them to STDERR (pass C<STDERR> as parameter), but STDOUT (C<STDOUT>) and a log file (C<logs/import_-date-.log>) (C<STATISTICS>) are also supported.
 
-=item C<--verbose>
-
-Set verbosity. Invoking the command with the --verbose, -v flag will render
-verbose output to the terminal.
-
 =back
 
 =head1 COMMANDS
@@ -159,30 +155,22 @@ It is possible to provide either all importer and/or exporter options on the
 command line, or to create a I<pipeline configuration file> that sets those
 options.
 
-=head2 L<transport [OPTIONS]|Datahub::Factory::Command::transport>
+=head2 transport [OPTIONS]
 
 Fetch data from a local or remote source, convert it to an exchange format and
 export the data.
 
-=head1 PLUGINS
-
-I<Datahub::Factory> uses a plugin-based architecture, making it easy to extend
-with new functionality.
-
-New commands can be added by creating a Perl module that contains a C<command_name.pm>
-file in the C<lib/Datahub/Factory/Command> path. I<Datahub::Factory> uses the
-L<Datahub::Factory::Command> namespace and L<App::Cmd> internally.
-
-New L<Datahub::Factory::Importer>, L<Exmporter|Datahub::Factory::Exporter> and L<Fixer|Datahub::Factory::Fixer> plugins
-can be added in the same way, in the C<lib/Datahub/Factory/Importer>, C<Exporter> or C<Fixer>
-path. All plugins use the I<Datahub::Factory::Importer/Exporter/Fixer> namespace and the
-namespace package as a L<Moose::Role>.
+L<Datahub::Factory::Command::transport>
 
 =head1 AUTHORS
 
-Pieter De Praetere <pieter@packed.be>
+=over
 
-Matthias Vandermaesen <matthias.vandermaesen@vlaamsekunstcollectie.be>
+=item Pieter De Praetere <pieter@packed.be>
+
+=item Matthias Vandermaesen <matthias.vandermaesen@vlaamsekunstcollectie.be>
+
+=back
 
 =head1 COPYRIGHT
 
