@@ -1,17 +1,17 @@
 package Datahub::Factory::Importer;
 
-use strict;
-use warnings;
+use Datahub::Factory::Sane;
 
 use Catmandu;
 use Moose::Role;
+use namespace::clean;
 
-has importer => (
-    is  => 'lazy'
-);
+has importer => (is  => 'lazy');
 has logger   => (is => 'lazy');
 has config   => (is => 'lazy');
 
+after _build_importer => sub { };
+
 sub _build_logger {
     my $self = shift;
     return Log::Log4perl->get_logger('datahub');
@@ -23,4 +23,4 @@ sub _build_config {
     return new Config::Simple('conf/settings.ini');
 }
 
-1;
\ No newline at end of file
+1;
